import { OnInit, OnDestroy, EventEmitter } from "@angular/core";
import { Comparator, State } from "clarity-angular";
import { Subscription } from "rxjs/Subscription";
import 'rxjs/add/observable/forkJoin';
import 'rxjs/add/observable/timer';
import { TranslateService } from "@ngx-translate/core";
import { ListReplicationRuleComponent } from "../list-replication-rule/list-replication-rule.component";
import { CreateEditRuleComponent } from "../create-edit-rule/create-edit-rule.component";
import { ErrorHandler } from "../error-handler/error-handler";
import { ReplicationService } from "../service/replication.service";
import { ReplicationRule, ReplicationJob, ReplicationJobItem } from "../service/interface";
import { JobLogViewerComponent } from "../job-log-viewer/index";
import { ConfirmationDialogComponent } from "../confirmation-dialog/confirmation-dialog.component";
import { ConfirmationAcknowledgement } from "../confirmation-dialog/confirmation-state-message";
import { OperationService } from "../operation/operation.service";
export declare class SearchOption {
    ruleId: number | string;
    ruleName: string;
    repoName: string;
    status: string;
    startTime: string;
    startTimestamp: string;
    endTime: string;
    endTimestamp: string;
    page: number;
    pageSize: number;
}
export declare class ReplicationComponent implements OnInit, OnDestroy {
    private errorHandler;
    private replicationService;
    private operationService;
    private translateService;
    projectId: number | string;
    projectName: string;
    isSystemAdmin: boolean;
    withReplicationJob: boolean;
    redirect: EventEmitter<ReplicationRule>;
    openCreateRule: EventEmitter<any>;
    openEdit: EventEmitter<string | number>;
    goToRegistry: EventEmitter<any>;
    search: SearchOption;
    ruleStatus: {
        [key: string]: any;
    };
    currentRuleStatus: {
        key: string;
        description: string;
    };
    jobStatus: {
        [key: string]: any;
    };
    currentJobStatus: {
        key: string;
        description: string;
    };
    changedRules: ReplicationRule[];
    rules: ReplicationRule[];
    loading: boolean;
    isStopOnGoing: boolean;
    hiddenJobList: boolean;
    jobs: ReplicationJobItem[];
    toggleJobSearchOption: {};
    currentJobSearchOption: number;
    listReplicationRule: ListReplicationRuleComponent;
    createEditPolicyComponent: CreateEditRuleComponent;
    replicationLogViewer: JobLogViewerComponent;
    replicationConfirmDialog: ConfirmationDialogComponent;
    creationTimeComparator: Comparator<ReplicationJob>;
    updateTimeComparator: Comparator<ReplicationJob>;
    currentPage: number;
    totalCount: number;
    pageSize: number;
    currentState: State;
    jobsLoading: boolean;
    timerDelay: Subscription;
    constructor(errorHandler: ErrorHandler, replicationService: ReplicationService, operationService: OperationService, translateService: TranslateService);
    readonly showPaginationIndex: boolean;
    ngOnInit(): void;
    ngOnDestroy(): void;
    openModal(): void;
    openEditRule(rule: ReplicationRule): void;
    goRegistry(): void;
    clrLoadJobs(state: State): void;
    loadFirstPage(): void;
    selectOneRule(rule: ReplicationRule): void;
    replicateManualRule(rule: ReplicationRule): void;
    confirmReplication(message: ConfirmationAcknowledgement): void;
    replicationOperate(rule: ReplicationRule): Promise<any>;
    customRedirect(rule: ReplicationRule): void;
    doSearchRules(ruleName: string): void;
    doFilterJobStatus($event: any): void;
    doSearchJobs(repoName: string): void;
    hideJobs(): void;
    stopJobs(): void;
    reloadRules(isReady: boolean): void;
    refreshRules(): void;
    refreshJobs(): void;
    toggleSearchJobOptionalName(option: number): void;
    doJobSearchByStartTime(fromTimestamp: string): void;
    doJobSearchByEndTime(toTimestamp: string): void;
    viewLog(jobId: number | string): void;
}
