import { Observable } from "rxjs/Observable";
import { RequestQueryParams } from "./RequestQueryParams";
import { AccessLog } from "./interface";
import "rxjs/add/observable/of";
import { IServiceConfig } from "../service.config";
import { Http } from "@angular/http";
/**
 * Define service methods to handle the access log related things.
 *
 * @export
 * @abstract
 * @class AccessLogService
 */
export declare abstract class AccessLogService {
    /**
     * Get the audit logs for the specified project.
     * Set query parameters through 'queryParams', support:
     *  - page
     *  - pageSize
     *
     * @abstract
     * @param {(number | string)} projectId
     * @param {RequestQueryParams} [queryParams]
     * @returns {(Observable<AccessLog> | Promise<AccessLog> | AccessLog)}
     *
     * @memberOf AccessLogService
     */
    abstract getAuditLogs(projectId: number | string, queryParams?: RequestQueryParams): Observable<AccessLog> | Promise<AccessLog> | AccessLog;
    /**
     * Get the recent logs.
     *
     * @abstract
     * @param {RequestQueryParams} [queryParams]
     * @returns {(Observable<AccessLog> | Promise<AccessLog> | AccessLog)}
     *
     * @memberOf AccessLogService
     */
    abstract getRecentLogs(queryParams?: RequestQueryParams): Observable<AccessLog> | Promise<AccessLog> | AccessLog;
}
/**
 * Implement a default service for access log.
 *
 * @export
 * @class AccessLogDefaultService
 * @extends {AccessLogService}
 */
export declare class AccessLogDefaultService extends AccessLogService {
    private http;
    private config;
    constructor(http: Http, config: IServiceConfig);
    getAuditLogs(projectId: number | string, queryParams?: RequestQueryParams): Observable<AccessLog> | Promise<AccessLog> | AccessLog;
    getRecentLogs(queryParams?: RequestQueryParams): Observable<AccessLog> | Promise<AccessLog> | AccessLog;
}
