import { Observable } from "rxjs/Observable";
import "rxjs/add/observable/of";
import { Http } from "@angular/http";
import { IServiceConfig } from "../service.config";
/**
 * Define the service methods to handle the job log related things.
 *
 * @export
 * @abstract
 * @class JobLogService
 */
export declare abstract class JobLogService {
    /**
     * Get the log of the specified job
     *
     * @abstract
     * @param {string} jobType
     * @param {(number | string)} jobId
     * @returns {(Observable<string> | Promise<string> | string)}
     * @memberof JobLogService
     */
    abstract getJobLog(jobType: string, jobId: number | string): Observable<string> | Promise<string> | string;
}
/**
 * Implement default service for job log service.
 *
 * @export
 * @class JobLogDefaultService
 * @extends {ReplicationService}
 */
export declare class JobLogDefaultService extends JobLogService {
    private http;
    _replicationJobBaseUrl: string;
    _scanningJobBaseUrl: string;
    _supportedJobTypes: string[];
    constructor(http: Http, config: IServiceConfig);
    _getJobLog(logUrl: string): Observable<string> | Promise<string> | string;
    _isSupportedJobType(jobType: string): boolean;
    getJobLog(jobType: string, jobId: number | string): Observable<string> | Promise<string> | string;
}
