import { OnInit, EventEmitter, ChangeDetectorRef, ElementRef, AfterViewInit } from "@angular/core";
import { Subject } from "rxjs/Subject";
import "rxjs/add/observable/forkJoin";
import { TranslateService } from "@ngx-translate/core";
import { State, Comparator } from "clarity-angular";
import { TagService } from "../service/index";
import { ErrorHandler } from "../error-handler/error-handler";
import { ChannelService } from "../channel/index";
import { ConfirmationDialogComponent } from "../confirmation-dialog/confirmation-dialog.component";
import { ConfirmationAcknowledgement } from "../confirmation-dialog/confirmation-state-message";
import { Label, Tag, TagClickEvent } from "../service/interface";
import { CopyInputComponent } from "../push-image/copy-input.component";
import { LabelService } from "../service/label.service";
import { OperationService } from "../operation/operation.service";
export interface LabelState {
    iconsShow: boolean;
    label: Label;
    show: boolean;
}
export declare class TagComponent implements OnInit, AfterViewInit {
    private errorHandler;
    private tagService;
    private labelService;
    private translateService;
    private ref;
    private operationService;
    private channel;
    signedCon: {
        [key: string]: any | string[];
    };
    projectId: number;
    repoName: string;
    isEmbedded: boolean;
    hasSignedIn: boolean;
    hasProjectAdminRole: boolean;
    isGuest: boolean;
    registryUrl: string;
    withNotary: boolean;
    withClair: boolean;
    withAdmiral: boolean;
    refreshRepo: EventEmitter<boolean>;
    tagClickEvent: EventEmitter<TagClickEvent>;
    signatureOutput: EventEmitter<any>;
    tags: Tag[];
    showTagManifestOpened: boolean;
    manifestInfoTitle: string;
    digestId: string;
    staticBackdrop: boolean;
    closable: boolean;
    lastFilteredTagName: string;
    inprogress: boolean;
    openLabelFilterPanel: boolean;
    openLabelFilterPiece: boolean;
    createdComparator: Comparator<Tag>;
    loading: boolean;
    copyFailed: boolean;
    selectedRow: Tag[];
    imageLabels: LabelState[];
    imageStickLabels: LabelState[];
    imageFilterLabels: LabelState[];
    labelListOpen: boolean;
    selectedTag: Tag[];
    labelNameFilter: Subject<string>;
    stickLabelNameFilter: Subject<string>;
    filterOnGoing: boolean;
    stickName: string;
    filterName: string;
    initFilter: {
        name: string;
        description: string;
        color: string;
        scope: string;
        project_id: number;
    };
    filterOneLabel: Label;
    confirmationDialog: ConfirmationDialogComponent;
    textInput: ElementRef;
    copyInput: CopyInputComponent;
    pageSize: number;
    currentPage: number;
    totalCount: number;
    currentState: State;
    constructor(errorHandler: ErrorHandler, tagService: TagService, labelService: LabelService, translateService: TranslateService, ref: ChangeDetectorRef, operationService: OperationService, channel: ChannelService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    readonly filterLabelPieceWidth: number;
    doSearchTagNames(tagName: string): void;
    clrLoad(state: State): void;
    refresh(): void;
    getAllLabels(): void;
    labelSelectedChange(tag?: Tag[]): void;
    addLabels(tag: Tag[]): void;
    stickLabel(labelInfo: LabelState): void;
    selectLabel(labelInfo: LabelState): void;
    unSelectLabel(labelInfo: LabelState): void;
    rightFilterLabel(labelInfo: LabelState): void;
    filterLabel(labelInfo: LabelState): void;
    unFilterLabel(labelInfo: LabelState): void;
    closeFilter(): void;
    openFlagEvent(isOpen: boolean): void;
    handleInputFilter(): void;
    handleStickInputFilter(): void;
    sortOperation(labelList: LabelState[], labelInfo: LabelState): void;
    retrieve(): void;
    sizeTransform(tagSize: string): string;
    deleteTags(tags: Tag[]): void;
    confirmDeletion(message: ConfirmationAcknowledgement): void;
    delOperate(tag: Tag): Promise<void>;
    showDigestId(tag: Tag[]): void;
    onTagClick(tag: Tag): void;
    onSuccess($event: any): void;
    onError($event: any): void;
    scanStatus(t: Tag): string;
    existObservablePackage(t: Tag): boolean;
    canScanNow(t: Tag[]): boolean;
    scanNow(t: Tag[]): void;
    onCpError($event: any): void;
}
